import math


def area_circle(radius=None, diameter=None):
    """
    Aah.. tough to remember me :
    Pie Are Squared... But they are round
    Enter the radius, diameter, circumference or area of a Circle to find the other three. The calculations are
    done "live":
    --------------
    if radius is given
    A = π r2
    π = 3.14159...

    if diameter is given
    A = (π/4) * D2
    --------------
    :param diameter:
    :param radius:
    :return: float
    """
    if radius is not None:
        area_by_radius = math.pi * (radius * radius)
        return area_by_radius
    if diameter is not None:
        area_by_diameter = (math.pi / 4) * (diameter * diameter)
        return area_by_diameter
    return None


result = area_circle(diameter=2.4)
print(result)



import setuptools
from distutils.core import setup


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="srmpy",
    version="0.1.0",
    author="Shailesh Mishra",
    author_email="mshaileshr@gmail.com",
    description="A package for mathematical calculations",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ishaileshmishra/srmpy.git",
    packages=setuptools.find_packages(),
    setup_requires=['wheel'],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    python_requires='>=3.6',
)
